/* generated file - DO NOT EDIT */

/* includes 247 stub entries, and 5 sentinel entries */

/*
*  declarations of normal stubs...
*  0 is QueryInterface
*  1 is AddRef
*  2 is Release
*/
#if !defined(__ia64) || (!defined(__hpux) && !defined(__linux__))
NS_IMETHOD Stub3();
NS_IMETHOD Stub4();
NS_IMETHOD Stub5();
NS_IMETHOD Stub6();
NS_IMETHOD Stub7();
NS_IMETHOD Stub8();
NS_IMETHOD Stub9();
NS_IMETHOD Stub10();
NS_IMETHOD Stub11();
NS_IMETHOD Stub12();
NS_IMETHOD Stub13();
NS_IMETHOD Stub14();
NS_IMETHOD Stub15();
NS_IMETHOD Stub16();
NS_IMETHOD Stub17();
NS_IMETHOD Stub18();
NS_IMETHOD Stub19();
NS_IMETHOD Stub20();
NS_IMETHOD Stub21();
NS_IMETHOD Stub22();
NS_IMETHOD Stub23();
NS_IMETHOD Stub24();
NS_IMETHOD Stub25();
NS_IMETHOD Stub26();
NS_IMETHOD Stub27();
NS_IMETHOD Stub28();
NS_IMETHOD Stub29();
NS_IMETHOD Stub30();
NS_IMETHOD Stub31();
NS_IMETHOD Stub32();
NS_IMETHOD Stub33();
NS_IMETHOD Stub34();
NS_IMETHOD Stub35();
NS_IMETHOD Stub36();
NS_IMETHOD Stub37();
NS_IMETHOD Stub38();
NS_IMETHOD Stub39();
NS_IMETHOD Stub40();
NS_IMETHOD Stub41();
NS_IMETHOD Stub42();
NS_IMETHOD Stub43();
NS_IMETHOD Stub44();
NS_IMETHOD Stub45();
NS_IMETHOD Stub46();
NS_IMETHOD Stub47();
NS_IMETHOD Stub48();
NS_IMETHOD Stub49();
NS_IMETHOD Stub50();
NS_IMETHOD Stub51();
NS_IMETHOD Stub52();
NS_IMETHOD Stub53();
NS_IMETHOD Stub54();
NS_IMETHOD Stub55();
NS_IMETHOD Stub56();
NS_IMETHOD Stub57();
NS_IMETHOD Stub58();
NS_IMETHOD Stub59();
NS_IMETHOD Stub60();
NS_IMETHOD Stub61();
NS_IMETHOD Stub62();
NS_IMETHOD Stub63();
NS_IMETHOD Stub64();
NS_IMETHOD Stub65();
NS_IMETHOD Stub66();
NS_IMETHOD Stub67();
NS_IMETHOD Stub68();
NS_IMETHOD Stub69();
NS_IMETHOD Stub70();
NS_IMETHOD Stub71();
NS_IMETHOD Stub72();
NS_IMETHOD Stub73();
NS_IMETHOD Stub74();
NS_IMETHOD Stub75();
NS_IMETHOD Stub76();
NS_IMETHOD Stub77();
NS_IMETHOD Stub78();
NS_IMETHOD Stub79();
NS_IMETHOD Stub80();
NS_IMETHOD Stub81();
NS_IMETHOD Stub82();
NS_IMETHOD Stub83();
NS_IMETHOD Stub84();
NS_IMETHOD Stub85();
NS_IMETHOD Stub86();
NS_IMETHOD Stub87();
NS_IMETHOD Stub88();
NS_IMETHOD Stub89();
NS_IMETHOD Stub90();
NS_IMETHOD Stub91();
NS_IMETHOD Stub92();
NS_IMETHOD Stub93();
NS_IMETHOD Stub94();
NS_IMETHOD Stub95();
NS_IMETHOD Stub96();
NS_IMETHOD Stub97();
NS_IMETHOD Stub98();
NS_IMETHOD Stub99();
NS_IMETHOD Stub100();
NS_IMETHOD Stub101();
NS_IMETHOD Stub102();
NS_IMETHOD Stub103();
NS_IMETHOD Stub104();
NS_IMETHOD Stub105();
NS_IMETHOD Stub106();
NS_IMETHOD Stub107();
NS_IMETHOD Stub108();
NS_IMETHOD Stub109();
NS_IMETHOD Stub110();
NS_IMETHOD Stub111();
NS_IMETHOD Stub112();
NS_IMETHOD Stub113();
NS_IMETHOD Stub114();
NS_IMETHOD Stub115();
NS_IMETHOD Stub116();
NS_IMETHOD Stub117();
NS_IMETHOD Stub118();
NS_IMETHOD Stub119();
NS_IMETHOD Stub120();
NS_IMETHOD Stub121();
NS_IMETHOD Stub122();
NS_IMETHOD Stub123();
NS_IMETHOD Stub124();
NS_IMETHOD Stub125();
NS_IMETHOD Stub126();
NS_IMETHOD Stub127();
NS_IMETHOD Stub128();
NS_IMETHOD Stub129();
NS_IMETHOD Stub130();
NS_IMETHOD Stub131();
NS_IMETHOD Stub132();
NS_IMETHOD Stub133();
NS_IMETHOD Stub134();
NS_IMETHOD Stub135();
NS_IMETHOD Stub136();
NS_IMETHOD Stub137();
NS_IMETHOD Stub138();
NS_IMETHOD Stub139();
NS_IMETHOD Stub140();
NS_IMETHOD Stub141();
NS_IMETHOD Stub142();
NS_IMETHOD Stub143();
NS_IMETHOD Stub144();
NS_IMETHOD Stub145();
NS_IMETHOD Stub146();
NS_IMETHOD Stub147();
NS_IMETHOD Stub148();
NS_IMETHOD Stub149();
NS_IMETHOD Stub150();
NS_IMETHOD Stub151();
NS_IMETHOD Stub152();
NS_IMETHOD Stub153();
NS_IMETHOD Stub154();
NS_IMETHOD Stub155();
NS_IMETHOD Stub156();
NS_IMETHOD Stub157();
NS_IMETHOD Stub158();
NS_IMETHOD Stub159();
NS_IMETHOD Stub160();
NS_IMETHOD Stub161();
NS_IMETHOD Stub162();
NS_IMETHOD Stub163();
NS_IMETHOD Stub164();
NS_IMETHOD Stub165();
NS_IMETHOD Stub166();
NS_IMETHOD Stub167();
NS_IMETHOD Stub168();
NS_IMETHOD Stub169();
NS_IMETHOD Stub170();
NS_IMETHOD Stub171();
NS_IMETHOD Stub172();
NS_IMETHOD Stub173();
NS_IMETHOD Stub174();
NS_IMETHOD Stub175();
NS_IMETHOD Stub176();
NS_IMETHOD Stub177();
NS_IMETHOD Stub178();
NS_IMETHOD Stub179();
NS_IMETHOD Stub180();
NS_IMETHOD Stub181();
NS_IMETHOD Stub182();
NS_IMETHOD Stub183();
NS_IMETHOD Stub184();
NS_IMETHOD Stub185();
NS_IMETHOD Stub186();
NS_IMETHOD Stub187();
NS_IMETHOD Stub188();
NS_IMETHOD Stub189();
NS_IMETHOD Stub190();
NS_IMETHOD Stub191();
NS_IMETHOD Stub192();
NS_IMETHOD Stub193();
NS_IMETHOD Stub194();
NS_IMETHOD Stub195();
NS_IMETHOD Stub196();
NS_IMETHOD Stub197();
NS_IMETHOD Stub198();
NS_IMETHOD Stub199();
NS_IMETHOD Stub200();
NS_IMETHOD Stub201();
NS_IMETHOD Stub202();
NS_IMETHOD Stub203();
NS_IMETHOD Stub204();
NS_IMETHOD Stub205();
NS_IMETHOD Stub206();
NS_IMETHOD Stub207();
NS_IMETHOD Stub208();
NS_IMETHOD Stub209();
NS_IMETHOD Stub210();
NS_IMETHOD Stub211();
NS_IMETHOD Stub212();
NS_IMETHOD Stub213();
NS_IMETHOD Stub214();
NS_IMETHOD Stub215();
NS_IMETHOD Stub216();
NS_IMETHOD Stub217();
NS_IMETHOD Stub218();
NS_IMETHOD Stub219();
NS_IMETHOD Stub220();
NS_IMETHOD Stub221();
NS_IMETHOD Stub222();
NS_IMETHOD Stub223();
NS_IMETHOD Stub224();
NS_IMETHOD Stub225();
NS_IMETHOD Stub226();
NS_IMETHOD Stub227();
NS_IMETHOD Stub228();
NS_IMETHOD Stub229();
NS_IMETHOD Stub230();
NS_IMETHOD Stub231();
NS_IMETHOD Stub232();
NS_IMETHOD Stub233();
NS_IMETHOD Stub234();
NS_IMETHOD Stub235();
NS_IMETHOD Stub236();
NS_IMETHOD Stub237();
NS_IMETHOD Stub238();
NS_IMETHOD Stub239();
NS_IMETHOD Stub240();
NS_IMETHOD Stub241();
NS_IMETHOD Stub242();
NS_IMETHOD Stub243();
NS_IMETHOD Stub244();
NS_IMETHOD Stub245();
NS_IMETHOD Stub246();
NS_IMETHOD Stub247();
NS_IMETHOD Stub248();
NS_IMETHOD Stub249();
#else
NS_IMETHOD Stub3(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub4(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub5(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub6(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub7(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub8(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub9(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub10(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub11(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub12(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub13(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub14(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub15(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub16(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub17(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub18(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub19(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub20(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub21(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub22(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub23(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub24(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub25(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub26(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub27(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub28(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub29(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub30(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub31(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub32(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub33(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub34(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub35(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub36(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub37(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub38(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub39(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub40(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub41(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub42(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub43(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub44(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub45(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub46(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub47(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub48(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub49(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub50(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub51(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub52(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub53(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub54(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub55(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub56(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub57(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub58(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub59(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub60(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub61(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub62(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub63(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub64(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub65(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub66(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub67(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub68(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub69(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub70(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub71(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub72(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub73(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub74(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub75(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub76(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub77(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub78(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub79(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub80(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub81(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub82(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub83(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub84(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub85(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub86(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub87(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub88(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub89(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub90(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub91(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub92(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub93(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub94(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub95(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub96(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub97(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub98(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub99(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub100(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub101(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub102(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub103(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub104(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub105(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub106(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub107(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub108(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub109(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub110(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub111(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub112(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub113(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub114(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub115(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub116(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub117(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub118(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub119(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub120(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub121(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub122(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub123(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub124(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub125(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub126(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub127(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub128(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub129(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub130(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub131(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub132(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub133(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub134(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub135(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub136(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub137(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub138(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub139(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub140(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub141(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub142(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub143(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub144(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub145(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub146(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub147(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub148(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub149(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub150(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub151(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub152(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub153(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub154(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub155(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub156(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub157(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub158(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub159(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub160(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub161(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub162(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub163(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub164(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub165(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub166(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub167(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub168(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub169(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub170(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub171(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub172(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub173(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub174(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub175(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub176(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub177(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub178(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub179(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub180(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub181(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub182(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub183(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub184(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub185(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub186(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub187(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub188(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub189(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub190(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub191(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub192(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub193(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub194(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub195(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub196(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub197(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub198(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub199(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub200(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub201(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub202(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub203(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub204(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub205(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub206(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub207(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub208(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub209(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub210(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub211(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub212(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub213(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub214(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub215(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub216(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub217(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub218(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub219(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub220(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub221(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub222(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub223(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub224(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub225(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub226(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub227(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub228(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub229(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub230(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub231(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub232(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub233(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub234(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub235(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub236(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub237(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub238(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub239(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub240(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub241(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub242(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub243(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub244(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub245(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub246(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub247(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub248(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
NS_IMETHOD Stub249(PRUint64,
 PRUint64,PRUint64,PRUint64,PRUint64,PRUint64,PRUint64);
#endif

/* declarations of sentinel stubs */
NS_IMETHOD Sentinel0();
NS_IMETHOD Sentinel1();
NS_IMETHOD Sentinel2();
NS_IMETHOD Sentinel3();
NS_IMETHOD Sentinel4();
