/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

interface nsIFile;

[uuid(10d1a2a2-d816-458d-a4c3-0805ff0f7b31)]
interface nsINativeComponentLoader : nsISupports
{

  /**
   *  addDependentLibrary
   *
   *  This method informs the native component loader that the 
   *  given component library referenced by |aFile| requires 
   *  symbols that can be found in the library named |aLibName|.
   *  
   *  The native component loader is expected to resolve these 
   *  external symobls prior to loading the component library.  
   *
   *  @param aFile
   *       The native component file location that is declaring a 
   *       a dependency. This file is expected to be a DSO/DLL.
   *
   *  @param aLibName
   *       This is a name of a library that the component requires.
   *       This file name is found in either the GRE bin directory 
   *       or the application's bin directory.  Full file path are 
   *       also accepted.  Passing nsnull for the |aLibName| will 
   *       clear all dependencies.  Note that non null aLibName
   *       values are expected to be in the native charset.
   */
  
  void addDependentLibrary(in nsIFile aFile, in string aLibName);
};
