/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /build/virtualbox/src/VirtualBox-7.2.16/src/libs/xpcom18a4/xpcom/io/nsIDirectoryEnumerator.idl
 */

#ifndef __gen_nsIDirectoryEnumerator_h__
#define __gen_nsIDirectoryEnumerator_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */


/* starting interface:    nsIDirectoryEnumerator */
#define NS_IDIRECTORYENUMERATOR_IID_STR "31f7f4ae-6916-4f2d-a81e-926a4e3022ee"

#define NS_IDIRECTORYENUMERATOR_IID \
  {0x31f7f4ae, 0x6916, 0x4f2d, \
    { 0xa8, 0x1e, 0x92, 0x6a, 0x4e, 0x30, 0x22, 0xee }}

class NS_NO_VTABLE nsIDirectoryEnumerator : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IDIRECTORYENUMERATOR_IID)

  /* readonly attribute nsIFile nextFile; */
  NS_IMETHOD GetNextFile(nsIFile * *aNextFile) = 0;

  /* void close (); */
  NS_IMETHOD Close(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDIRECTORYENUMERATOR \
  NS_IMETHOD GetNextFile(nsIFile * *aNextFile) NS_OVERRIDE; \
  NS_IMETHOD Close(void) NS_OVERRIDE; 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDIRECTORYENUMERATOR(_to) \
  NS_IMETHOD GetNextFile(nsIFile * *aNextFile) { return _to GetNextFile(aNextFile); } \
  NS_IMETHOD Close(void) { return _to Close(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDIRECTORYENUMERATOR(_to) \
  NS_IMETHOD GetNextFile(nsIFile * *aNextFile) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNextFile(aNextFile); } \
  NS_IMETHOD Close(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Close(); } 


#endif /* __gen_nsIDirectoryEnumerator_h__ */
